@@ -1,5 +1,4 @@
 from arkdriver.driver.application import Application
-from arkdriver.driver.admin import Admin
 from arkdriver.driver.driver import Driver
 
-__all__ = ['Admin', 'Application', 'Driver']
+__all__ = ['Application', 'Driver']
